( cd usr/lib ; rm -rf libaviplay-0.7.so.0 )
( cd usr/lib ; ln -sf libaviplay-0.7.so.0.0.45 libaviplay-0.7.so.0 )
( cd usr/lib ; rm -rf libaviplayavutil-0.7.so.0 )
( cd usr/lib ; ln -sf libaviplayavutil-0.7.so.0.0.45 libaviplayavutil-0.7.so.0 )
( cd usr/lib ; rm -rf libqavm-0.7.so.0 )
( cd usr/lib ; ln -sf libqavm-0.7.so.0.0.45 libqavm-0.7.so.0 )
( cd usr/lib ; rm -rf libaviplaydha.so )
( cd usr/lib ; ln -sf libaviplaydha-0.7.so.0.0.45 libaviplaydha.so )
( cd usr/lib ; rm -rf libaviplay.so )
( cd usr/lib ; ln -sf libaviplay-0.7.so.0.0.45 libaviplay.so )
( cd usr/lib ; rm -rf libaviplaydha-0.7.so.0 )
( cd usr/lib ; ln -sf libaviplaydha-0.7.so.0.0.45 libaviplaydha-0.7.so.0 )
( cd usr/lib ; rm -rf libaviplayavcodec.so )
( cd usr/lib ; ln -sf libaviplayavcodec-0.7.so.0.0.45 libaviplayavcodec.so )
( cd usr/lib ; rm -rf libaviplayavutil.so )
( cd usr/lib ; ln -sf libaviplayavutil-0.7.so.0.0.45 libaviplayavutil.so )
( cd usr/lib ; rm -rf libaviplayvidix.so )
( cd usr/lib ; ln -sf libaviplayvidix-0.7.so.0.0.45 libaviplayvidix.so )
( cd usr/lib ; rm -rf libaviplayvidix-0.7.so.0 )
( cd usr/lib ; ln -sf libaviplayvidix-0.7.so.0.0.45 libaviplayvidix-0.7.so.0 )
( cd usr/lib ; rm -rf libaviplayavformat.so )
( cd usr/lib ; ln -sf libaviplayavformat-0.7.so.0.0.45 libaviplayavformat.so )
( cd usr/lib ; rm -rf libaviplayavformat-0.7.so.0 )
( cd usr/lib ; ln -sf libaviplayavformat-0.7.so.0.0.45 libaviplayavformat-0.7.so.0 )
( cd usr/lib ; rm -rf libqavm.so )
( cd usr/lib ; ln -sf libqavm-0.7.so.0.0.45 libqavm.so )
( cd usr/lib ; rm -rf libaviplayavcodec-0.7.so.0 )
( cd usr/lib ; ln -sf libaviplayavcodec-0.7.so.0.0.45 libaviplayavcodec-0.7.so.0 )
